# Cunning Document Scanner

Cunning Document Scanner is a Flutter-based document scanner application that enables you to capture images of paper documents and convert them into digital files effortlessly. This application is designed to run on Android and iOS devices with minimum API levels of 21 and 13, respectively.

## Key Features

- Fast and easy document scanning.
- Conversion of document images into digital files.
- Support for both Android and iOS platforms.
- Minimum requirements: API 21 on Android, iOS 13 on iOS.
- Limit the number of scannable files on Android.
- Allows selection of images from the gallery on Android.

A state of the art document scanner with automatic cropping function.

<img src="https://user-images.githubusercontent.com/1488063/167291601-c64db2d5-78ab-4781-bc7a-afe7eb93e083.png" height ="400"  alt=""/>
<img src="https://user-images.githubusercontent.com/1488063/167291821-3b66d0bb-b636-4911-a572-d2368dc95012.jpeg" height ="400"  alt=""/>
<img src="https://user-images.githubusercontent.com/1488063/167291827-fa0ae804-1b81-4ef4-8607-3b212c3ab1c0.jpeg" height ="400"  alt=""/>

## Project Setup
Follow the steps below to set up your Flutter project on Android and iOS.

### **Android**

#### Minimum Version Configuration
Ensure you meet the minimum version requirements to run the application on Android devices.
In the `android/app/build.gradle` file, verify that `minSdkVersion` is at least 21:

```gradle
android {
    ...
    defaultConfig {
        ...
        minSdkVersion 21
        ...
    }
    ...
}
```

### **IOS**
#### Minimum Version Configuration
Ensure you meet the minimum version requirements to run the application on iOS devices.
In the `ios/Podfile` file, make sure the iOS platform version is at least 13.0:

```ruby
platform :ios, '13.0'
```
#### Permission Configuration
1. Add a String property to the app's Info.plist file with the key [NSCameraUsageDescription](https://developer.apple.com/documentation/bundleresources/information_property_list/nscamerausagedescription) and the value as the description for why your app needs camera access.

   <key>NSCameraUsageDescription</key>
   <string>Camera Permission Description</string>

2. The [permission_handler](https://pub.dev/packages/permission_handler) dependency used by cunning_document_scanner use [macros](https://github.com/Baseflow/flutter-permission-handler/blob/master/permission_handler_apple/ios/Classes/PermissionHandlerEnums.h) to control whether a permission is enabled. Add the following to your `Podfile` file:

   ```ruby
   post_install do |installer|
     installer.pods_project.targets.each do |target|
       ... # Here are some configurations automatically generated by flutter

       # Start of the permission_handler configuration
       target.build_configurations.each do |config|

         # You can enable the permissions needed here. For example to enable camera
         # permission, just remove the `#` character in front so it looks like this:
         #
         # ## dart: PermissionGroup.camera
         # 'PERMISSION_CAMERA=1'
         #
         #  Preprocessor definitions can be found at: https://github.com/Baseflow/flutter-permission-handler/blob/master/permission_handler_apple/ios/Classes/PermissionHandlerEnums.h
         config.build_settings['GCC_PREPROCESSOR_DEFINITIONS'] ||= [
           '$(inherited)',

           ## dart: PermissionGroup.camera
           'PERMISSION_CAMERA=1',
         ]

       end
       # End of the permission_handler configuration
     end
   end
   ```

## How to use ?

The easiest way to get a list of images is:

```
    final imagesPath = await CunningDocumentScanner.getPictures()
```
### Android Specific

There are some features in Android that allow you to adjust the scanner that will be ignored in iOS:

```
    final imagesPath = await CunningDocumentScanner.getPictures(
      noOfPages: 1, // Limit the number of pages to 1
      isGalleryImportAllowed, // Allow the user to also pick an image from his gallery
   )
```

## Installation

Before you begin, make sure you have Flutter and Dart installed on your system. You can follow the [Flutter installation guide](https://flutter.dev/docs/get-started/install) for more information.

1. Clone this repository:

   ```bash
   git clone https://github.com/jachzen/cunning_document_scanner.git
   ```

2. Navigate to the project directory:

   ```bash
   cd cunning_document_scanner
   ```

3. Install dependencies:

   ```bash
   flutter pub get
   ```

4. Run the application:

   ```bash
   flutter run
   ```

## Contributions

Contributions are welcome. If you want to contribute to the development of Cunning Document Scanner, follow these steps:

1. Fork the repository.
2. Create a branch for your contribution: `git checkout -b your_feature`
3. Make your changes and commit: `git commit -m 'Add a new feature'`
4. Push the branch: `git push origin your_feature`
5. Open a pull request on GitHub.

## Issues and Support

If you encounter any issues or have questions, please open an [issue](https://github.com/jachzen/cunning_document_scanner/issues). We're here to help.

## License

This project is licensed under the MIT License. See the [LICENSE](LICENSE) file for more details.